@@ -2,7 +2,9 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendariu",
-    "%s has published the calendar \"%s\"" : "%s espublizó'l calendariu «%s»",
+    "Hello," : "Hola,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Quiximos informate de que %s espublizó'l calendariu «%s»",
+    "Cheers!" : "¡Salú!",
     "Too many redirects. Aborting ..." : "Milenta redireiciones. Albortando...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "El sirvidor remotu nun mos dio accesu al calendariu (fallu HTTP {%s})",
     "Error connecting to remote server" : "Fallu coneutando col sirvidor remotu",
@@ -20,10 +22,9 @@ OC.L10N.register(
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Tas nunca zona horaria desconocia  ({tz}), torna a UTC",
     "Please create a calendar first." : "Por favor, crea entantes un calendariu.",
     "New event" : "Eventu nuevu",
+    "CalDAV address for clients" : "Direición CalDAV pa veceros",
     "Error saving WebCal-calendar" : "Fallu guardando'l calendariu WebCal",
     "WebDAV address for subscriptions" : "Direición WebDAV pa soscripciones",
-    "EMail has been sent." : "Unvióse'l corréu.",
-    "There was an issue while sending your EMail." : "Hebo un problema entrín s'unviaba'l to corréu.",
     "group" : "grupu",
     "Details" : "Detalles",
     "Attendees" : "Asistentes",
@@ -35,8 +36,7 @@ OC.L10N.register(
     "Confirmed" : "Confirmáu",
     "Tentative" : "Tentativa",
     "Cancelled" : "Encaboxáu",
-    "Please add a title!" : "¡Por favor, amiesta un títulu!",
-    "Please select a calendar!" : "¡Por favor, esbilla un calendariu!",
+    "The event can not end before it starts." : "L'eventu nun pue finar enantes de qu'entame.",
     "Global" : "Global",
     "None" : "Dengún",
     "Every day" : "Caldía",
@@ -54,8 +54,7 @@ OC.L10N.register(
     "2 hours before" : "2 hores enantes",
     "Custom" : "Personalizáu",
     "Audio" : "Audiu",
-    "E Mail" : "Corréu",
-    "Pop up" : "Ventanu emerxente",
+    "Pop-up" : "Ventanu emerxente",
     "sec" : "seg",
     "min" : "mín.",
     "hours" : "hores",
@@ -70,8 +69,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Importáu parcialmente, 1 fallu",
     "Partially imported, {n} failures" : "Importáu parcialmente, {n} fallos",
     "Audio alarm" : "Alarma d'audiu",
-    "Pop-up" : "Ventanu emerxente",
-    "E-Mail" : "Corréu",
     "{type} {time} before the event starts" : "{type} {time} enantes que l'enventu entame",
     "{type} {time} before the event ends" : "{type} {time} enantes que l'eventu fine",
     "{type} {time} after the event starts" : "{type} {time} dempués que l'eventu entame",
@@ -93,10 +90,8 @@ OC.L10N.register(
     "Event status" : "Estáu del eventu",
     "Visibility when sharing" : "Visibilida mientres compartes",
     "Export" : "Esportar",
-    "Hello," : "Hola,",
-    "Cheers!" : "¡Salú!",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Por cuenta d'un bug d'upstream, el calendariu nun soporta la carauterística d'asset pipeline",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contauta col to alministrador y pídi-y que desactive la opción de configuración \"asset-pipeline.enabled\".",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Quiximos informate de que %s espublizó'l calendariu {boldstart}%s{boldend}.",
+    "We wanted to inform you that %s has published the calendar %s." : "Quiximos informate de que %s espublizó'l calendariu %s.",
     "Day" : "Día",
     "Week" : "Selmana",
     "Month" : "Mes",
@@ -128,7 +123,6 @@ OC.L10N.register(
     "Repeat" : "Repitir",
     "times every" : "cada vegada",
     "Add" : "Amestar",
-    "E-Mail address of attendee" : "Direición de corréu del asistente",
     "Please add your email address in the personal settings in order to add attendees." : "Por favor amiesta'l to corréu nos axustes de la so cuenta p'amestar asistentes",
     "from" : "Dende",
     "to" : "hasta",
