@@ -2,7 +2,8 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Календар",
-    "%s has published the calendar \"%s\"" : "%s публикува календарът \"%s\"",
+    "Hello," : "Здравей, ",
+    "Cheers!" : "Поздрави!",
     "Too many redirects. Aborting ..." : "Прекалено много пренасочвания. Прекъсване ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Отдалечения сървър не предостави достъп до календара (HTTP {%s} грешка)",
     "Error connecting to remote server" : "Грешка при свързване с отдалечен сървър",
@@ -23,8 +24,6 @@ OC.L10N.register(
     "CalDAV address for clients" : "CalDAV адрес за клиенти",
     "Error saving WebCal-calendar" : "Грешка при запаметяване на WebCal-календар",
     "WebDAV address for subscriptions" : "WebDAV адрес за абонаменти",
-    "EMail has been sent." : "Имейлът е изпратен.",
-    "There was an issue while sending your EMail." : "Възникна грешка по време на изпращане на писмото ви.",
     "group" : "група",
     "Details" : "Детайли",
     "Attendees" : "Присъстващи",
@@ -36,9 +35,6 @@ OC.L10N.register(
     "Confirmed" : "Потвърдено",
     "Tentative" : "Несигурно",
     "Cancelled" : "Отказано",
-    "Please add a title!" : "Моля добавете заглавие!",
-    "Please select a calendar!" : "Моля изберете календар!",
-    "The event ends before it starts!" : "Събитието приключва преди да е започнало!",
     "Global" : "Глобално",
     "None" : "Няма",
     "Every day" : "Всеки ден",
@@ -57,8 +53,7 @@ OC.L10N.register(
     "2 hours before" : "2 часа преди ",
     "Custom" : "Избирателно",
     "Audio" : "Аудио",
-    "E Mail" : "Електронна поща",
-    "Pop up" : "Изкачащ прозорец",
+    "Pop-up" : "Изкачащ прозорец",
     "sec" : "секунда",
     "min" : "минимално",
     "hours" : "часове",
@@ -73,8 +68,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Частично въвеждане, 1 грешка",
     "Partially imported, {n} failures" : "Частично въвеждане, {n} грешки",
     "Audio alarm" : "Звуков сигнал",
-    "Pop-up" : "Изкачащ прозорец",
-    "E-Mail" : "Електронна поща",
     "{type} {time} before the event starts" : "{type} {time} преди началото на събитието",
     "{type} {time} before the event ends" : "{type} {time} преди края на събитието",
     "{type} {time} after the event starts" : "{type} {time} след началото на събитието",
@@ -101,14 +94,10 @@ OC.L10N.register(
     "Visibility when sharing" : "Видимост при споделяне",
     "Export" : "Експорт",
     "%s has published the calendar %s" : "%s публикува календарът \"%s\"",
-    "Hello," : "Здравей, ",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Искаме да те информираме че %s е публикувал календар {boldstart}%s{boldend}.",
     "Click here to access it" : "Натисни тук за да го достъпиш",
-    "Cheers!" : "Поздрави!",
     "We wanted to inform you that %s has published the calendar %s." : "Искаме да те информираме че %s е публикувал календар %s.",
     "Click on the link below to access it" : "Натисни на връзката отдолу за да го достъпиш ",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Поради грешка в по-нови версии, календара не е способен да предостави поддръжка за функционалността поток на активи.",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Свържи се с администратора с молба за изключване на \"asset-pipeline.enabled\" конфигурационна опция.",
     "Day" : "Ден",
     "Week" : "Седмица",
     "Month" : "Месец",
@@ -144,7 +133,6 @@ OC.L10N.register(
     "Repeat" : "Да се повтаря",
     "times every" : "на всеки",
     "Add" : "Добави",
-    "E-Mail address of attendee" : "Имейл адрес на участник",
     "Please add your email address in the personal settings in order to add attendees." : "Добави e-mail адреса си в личните настройки за да можеш да добавяш участници.",
     "from" : "от",
     "to" : "до",
@@ -163,7 +151,6 @@ OC.L10N.register(
     "Import scheduled" : "Внасянето насрочено",
     "%s shared the calendar <strong>%s</strong> with you" : "%s сподели календарът <strong>%s</strong> с вас",
     "Embed" : "Вграден",
-    "IFrame to integrate" : "Рамка за вграждане",
     "Publish URL" : "Публикувай URL",
     "Settings & import" : "Настройки и внасяне",
     "Skip simple event editor" : "Пропусни опростения редактор за събития",
