@@ -2,7 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
-    "%s has published the calendar \"%s\"" : "%s har offentliggjort kalenderen \"%s\"",
+    "%s has published the calendar »%s«" : "%s har oprettet en begivenhed i kalenderen »%s«",
+    "Hello," : "Hej,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønkser at informerer dig om at %s har oprettet en begivenhed i kalenderen »%s«.",
+    "Open »%s«" : "Åben »%s«",
+    "Cheers!" : "Hav en fortsat god dag.",
+    "Recipient" : "Modtager",
     "Too many redirects. Aborting ..." : "For mange omdirigeringer. Afbryder ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serveren gav os ikke adgang til kalenderen (HTTP {%s} fejl)",
     "Error connecting to remote server" : "Fejl ved forbindelse til serveren",
@@ -23,12 +28,12 @@ OC.L10N.register(
     "CalDAV address for clients" : "CalDAV addresse for klienter",
     "Error saving WebCal-calendar" : "Kunne ikke gemme WebCal-kalender",
     "WebDAV address for subscriptions" : "WeblDAV addresse for abonnementer",
-    "EMail has been sent." : "Email afsendt",
-    "There was an issue while sending your EMail." : "Der var et problem ved afsendelse af din Email.",
+    "Email has been sent." : "E-mailen er sendt.",
+    "There was an issue while sending your email." : "Der opstod en fejl i forsøget på at sende din e-mail",
     "group" : "gruppe",
     "Details" : "Detaljer",
     "Attendees" : "Deltagere",
-    "Reminders" : "Påmindindelser",
+    "Reminders" : "Påmindelser",
     "Repeating" : "Gentagende",
     "When shared show full event" : "Når delt, vis den fulde begivenhed",
     "When shared show only busy" : "Når delt, vis kun optaget",
@@ -36,9 +41,9 @@ OC.L10N.register(
     "Confirmed" : "Bekræftet",
     "Tentative" : "Foreløbig prøve",
     "Cancelled" : "Annulléret",
-    "Please add a title!" : "Vær venlig at tilføje en titel!",
-    "Please select a calendar!" : "Vælg venligt kalender",
-    "The event ends before it starts!" : "Begivenheden slutter før den starter!",
+    "Please add a title." : "Indtast venligst en titel.",
+    "Please select a calendar." : "Vælg venligst en kalender.",
+    "The event can not end before it starts." : "Begivenheden kan ikke stoppe før den starter",
     "Global" : "Global",
     "None" : "Ingen",
     "Every day" : "Hver dag",
@@ -57,8 +62,8 @@ OC.L10N.register(
     "2 hours before" : "2 timer før",
     "Custom" : "Valgfrit",
     "Audio" : "Lyd",
-    "E Mail" : "E-mail",
-    "Pop up" : "Pop-up",
+    "Email" : "E-mail",
+    "Pop-up" : "Pop-up",
     "sec" : "sek",
     "min" : "min.",
     "hours" : "timer",
@@ -73,8 +78,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Delvist importeret, 1 fejl",
     "Partially imported, {n} failures" : "Delvist importeret, {n} fejl",
     "Audio alarm" : "Lyd alarm",
-    "Pop-up" : "Pop-up",
-    "E-Mail" : "E-mail",
     "{type} {time} before the event starts" : "{type} {time} før begivenheden begynder",
     "{type} {time} before the event ends" : "{type} {time} før begivenheden slutter",
     "{type} {time} after the event starts" : "{type} {time} efter begivenheden begynder",
@@ -101,14 +104,10 @@ OC.L10N.register(
     "Visibility when sharing" : "Synlighed ved deling",
     "Export" : "Eksportér",
     "%s has published the calendar %s" : "%s har offentliggjort kalenderen %s",
-    "Hello," : "Hej,",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen {boldstart}%s{boldend}.",
     "Click here to access it" : "Klik her for at få adgang til den",
-    "Cheers!" : "Hav en fortsat god dag.",
     "We wanted to inform you that %s has published the calendar %s." : "Vi ønskede at informere dig om at %s har offentliggjort kalenderen %s.",
     "Click on the link below to access it" : "Klik på linket under for at få adgang til den",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "På grund af en \"upstream bug\", er kalenderen, i øjeblikket, ikke i stand til at understøtte funktionen \"asset pipeline\".",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt venligst din administrator og bed om at \"asset-pipeline.enabled\" bliver slået fra.",
     "Day" : "Dag",
     "Week" : "Uge",
     "Month" : "Måned",
@@ -132,6 +131,8 @@ OC.L10N.register(
     "New Subscription" : "Tilføj abonnement",
     "Go back" : "Gå tilbage",
     "Go forward" : "Gå frem",
+    "Calendar does not exist" : "Kalenderen eksisterer ikke",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Måske har du fået et forkert link eller delingen af kalenderen er blevet fjernet",
     "Edit event" : "Rediger begivenhed",
     "Delete Event" : "Slet begivenhed",
     "Save Event" : "Gem begivenhed",
@@ -142,7 +143,7 @@ OC.L10N.register(
     "Repeat" : "Gentag",
     "times every" : "gange hver",
     "Add" : "Tilføj",
-    "E-Mail address of attendee" : "E-mailadresse på deltager",
+    "Email address of attendee" : "E-mail på deltager",
     "Please add your email address in the personal settings in order to add attendees." : "Tilføj din e-mailadresse under Personlige indstillinger for at kunne invitere deltagere.",
     "from" : "fra",
     "to" : "til",
@@ -159,6 +160,9 @@ OC.L10N.register(
     "New calendar" : "Ny kalender",
     "File is empty" : "Fil er tom",
     "Import scheduled" : "Importering planlagt",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s delte kalenderen <strong>%s</strong> med dig",
+    "Embed" : "Embed",
+    "Iframe to integrate" : "Iframe der skal integreres",
     "Publish URL" : "Offentliggør URL",
     "Settings & import" : "Indstillinger & importer",
     "Skip simple event editor" : "Spring over enkel begivenheds tekstbehandler",
@@ -166,6 +170,7 @@ OC.L10N.register(
     "Import calendar" : "Importer kalender",
     "No Calendars selected for import" : "Ingen kalendere er valgt til importering",
     "Primary CalDAV address" : "Primær CalDAV-adresse",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-adresse"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV-adresse",
+    "Subscribe" : "Tilmeld"
 },
 "nplurals=2; plural=(n != 1);");
