@@ -2,9 +2,14 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
-    "%s has published the calendar \"%s\"" : "%s hat den Kalender \"%s\" veröffentlicht",
-    "Too many redirects. Aborting ..." : "Zu viele Umleitungen. Abbruch ...",
-    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Der entfernte Server erlaubt keinen Zugriff auf den Kalender (HTTP {%s} error)",
+    "%s has published the calendar »%s«" : "%s hat den Kalender »%s« veröffentlicht",
+    "Hello," : "Hallo,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Wir möchten Dich informieren, dass %s den Kalender »%s« veröffentlicht hat.",
+    "Open »%s«" : "»%s« öffnen",
+    "Cheers!" : "Noch einen schönen Tag!",
+    "Recipient" : "Empfänger",
+    "Too many redirects. Aborting ..." : "Zu viele Umleitungen. Abbruch…",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Der entfernte Server erlaubt keinen Zugriff auf den Kalender (HTTP {%s} Fehler)",
     "Error connecting to remote server" : "Fehler bei der Verbindung zum entfernten Server",
     "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Fehler beim Abrufen einer Resource auf dem entfernten Server. Dies könnte mit einem Zertifikatsfehler zusammenhängen.",
     "Error requesting resource on remote server" : "Fehler beim Abruf einer Resource auf dem entfernten Server",
@@ -17,36 +22,36 @@ OC.L10N.register(
     "Optional" : "Optional",
     "Does not attend" : "Nimmt nicht teil",
     "{name} ({email})" : "{name} ({email})",
-    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bist in einer unbekannten Zeitzone ({tz}), Verwendung von UTC als Ersatz",
-    "Please create a calendar first." : "Bitte erstelle zuerst einen Kalender.",
+    "You are in an unknown timezone ({tz}), falling back to UTC" : "Du bist in einer unbekannten Zeitzone ({tz}), es wird auf UTC geändert",
+    "Please create a calendar first." : "Bitte zuerst einen Kalender erstellen.",
     "New event" : "Neues Ereignis",
     "CalDAV address for clients" : "CalDAV-Adresse für Clients",
     "Error saving WebCal-calendar" : "Fehler beim Speichern des WebCal-Kalenders",
     "WebDAV address for subscriptions" : "WebDAV-Adresse für Abonnements",
-    "EMail has been sent." : "E-Mail wurde versendet.",
-    "There was an issue while sending your EMail." : "Es ist ein Fehler beim Versenden der E-Mail aufgetreten.",
+    "Email has been sent." : "E-Mail versandt",
+    "There was an issue while sending your email." : "Beim Versand der E-Mail ist ein Fehler aufgetreten",
     "group" : "Gruppe",
     "Details" : "Details",
     "Attendees" : "Teilnehmer",
     "Reminders" : "Erinnerungen",
-    "Repeating" : "Wiederholend",
-    "When shared show full event" : "Wenn geteilt, ganzes Ereignis anzeigen",
-    "When shared show only busy" : "Wenn geteilt, nur den Status beschäftigt anzeigen",
-    "When shared hide this event" : "Wenn geteilt, Ereignis verstecken",
+    "Repeating" : "Wiederholen",
+    "When shared show full event" : "Wenn geteilt, zeige das vollständige Ereignis an",
+    "When shared show only busy" : "wenn geteilt, zeige nur den Status 'beschäftigt' an",
+    "When shared hide this event" : "Wenn geteilt, zeige das Ereignis nicht an",
     "Confirmed" : "Bestätigt",
     "Tentative" : "Vorläufig",
     "Cancelled" : "Abgesagt",
-    "Please add a title!" : "Bitte einen Titel hinzufügen!",
-    "Please select a calendar!" : "Bitte einen Kalender auswählen!",
-    "The event ends before it starts!" : "Das Ereignis endet bevor es startet!",
+    "Please add a title." : "Bitte einen Titel hinzufügen.",
+    "Please select a calendar." : "Bitte einen Kalender auswählen.",
+    "The event can not end before it starts." : "Das Ereignis endet bevor es startet.",
     "Global" : "Global",
     "None" : "Keine",
-    "Every day" : "jeden Tag",
-    "Every week" : "jede Woche",
-    "Every month" : "jeden Monat",
-    "Every year" : "jedes Jahr",
-    "never" : "niemals",
-    "after" : "nach",
+    "Every day" : "Jeden Tag",
+    "Every week" : "Jede Woche",
+    "Every month" : "Jeden Monat",
+    "Every year" : "Jedes Jahr",
+    "never" : "Niemals",
+    "after" : "Nach",
     "How about getting started by importing some calendars?" : "Wie wäre es, wenn du damit beginnen würdest einige Kalender zu importieren?",
     "At time of event" : "Zum Zeitpunkt des Ereignisses",
     "5 minutes before" : "5 Minuten vorher",
@@ -55,31 +60,29 @@ OC.L10N.register(
     "30 minutes before" : "30 Minuten vorher",
     "1 hour before" : "1 Stunde vorher",
     "2 hours before" : "2 Stunden vorher",
-    "Custom" : "benutzerdefiniert",
+    "Custom" : "Benutzerdefiniert",
     "Audio" : "Audio",
-    "E Mail" : "E-Mail",
-    "Pop up" : "Pop-up",
-    "sec" : "s",
-    "min" : "min",
+    "Email" : "E-Mail",
+    "Pop-up" : "Pop-up",
+    "sec" : "Sek",
+    "min" : "Min",
     "hours" : "Stunden",
-    "days" : "Tagen",
+    "days" : "Tage",
     "week" : "Woche",
-    "before" : "vorher",
+    "before" : "vor",
     "start" : "Start",
     "end" : "Ende",
     "Editing reminders of unknown type not supported." : "Das Ändern von Erinnerungen unbekannten Typs wird nicht unterstützt.",
-    "Week {number} of {year}" : "Woche {number} von {year}",
+    "Week {number} of {year}" : "Woche {number} aus {year}",
     "Successfully imported" : "Erfolgreich importiert",
     "Partially imported, 1 failure" : "Teilweise importiert, 1 Fehler",
-    "Partially imported, {n} failures" : "Teilweise importiert , {n} Fehler",
+    "Partially imported, {n} failures" : "Teilweise importiert, {n} Fehler",
     "Audio alarm" : "Akustischer Alarm",
-    "Pop-up" : "Pop-up",
-    "E-Mail" : "E-Mail",
     "{type} {time} before the event starts" : "{type} {time} vor Beginn des Ereignisses",
     "{type} {time} before the event ends" : "{type} {time} vor Ende des Ereignisses",
     "{type} {time} after the event starts" : "{type} {time} nach Beginn des Ereignisses",
     "{type} {time} after the event ends" : "{type} {time} nach Ende des Ereignisses",
-    "{type} at the event's start" : "{type} am Beginn des Ereignisses",
+    "{type} at the event's start" : "{type} zu Beginn der Ereignisses",
     "{type} at the event's end" : "{type} am Ende des Ereignisses",
     "{type} at {time}" : "{type} um {time}",
     "{calendar} shared by {owner}" : "{calendar} geteilt von {owner}",
@@ -101,14 +104,10 @@ OC.L10N.register(
     "Visibility when sharing" : "Sichtbarkeit wenn geteilt",
     "Export" : "Exportieren",
     "%s has published the calendar %s" : "%s hat den Kalender %s veröffentlicht",
-    "Hello," : "Hallo,",
-    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Wir wollten dich informieren, dass %s den Kalender {boldstart}%s{boldend} veröffentlicht hat.",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Wir wollen Dich informieren, dass %s den Kalender {boldstart}%s{boldend} veröffentlicht hat.",
     "Click here to access it" : "Klicke hier, um darauf zuzugreifen",
-    "Cheers!" : "Danke!",
     "We wanted to inform you that %s has published the calendar %s." : "Wir möchten Dich darüber informieren, dass %s den Kalender %s veröffentlicht hat.",
     "Click on the link below to access it" : "Klicke auf den Link unten, um darauf zuzugreifen",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Aufgrund eines Softwarefehlers ist der Kalender zur Zeit nicht in der Lage, die Asset-Pipeline-Funktion zu unterstützen.",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Bitte kontaktiere deinen Administrator und bitte ihn, die Konfigurationsoption \"asset-pipeline.enabled\" zu deaktivieren.",
     "Day" : "Tag",
     "Week" : "Woche",
     "Month" : "Monat",
@@ -119,7 +118,7 @@ OC.L10N.register(
     "More" : "Mehr",
     "Edit" : "Bearbeiten",
     "Link" : "Link",
-    "iCal link" : "iCal Link",
+    "iCal link" : "iCal-Link",
     "Download" : "Herunterladen",
     "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
     "can edit" : "kann bearbeiten",
@@ -144,26 +143,26 @@ OC.L10N.register(
     "Repeat" : "Wiederholen",
     "times every" : "mal pro",
     "Add" : "Hinzufügen",
-    "E-Mail address of attendee" : "E-Mail-Adresse des Teilnehmers",
-    "Please add your email address in the personal settings in order to add attendees." : "Bitte gib deine E-Mail-Adresse in den Persönlichen Einstellungen an, um Teilnehmer hinzuzufügen.",
+    "Email address of attendee" : "E-Mail-Adresse des Teilnehmers",
+    "Please add your email address in the personal settings in order to add attendees." : "Bitte füge Deine E-Mail-Adresse in den persönlichen Einstellungen hinzu, um Teilnehmer hinzufügen zu können. ",
     "from" : "von",
     "to" : "an",
     "This event's repeating rule is not supported yet." : "Die Wiederholungsregel dieses Ereignisses wird noch nicht unterstützt.",
     "Support for advanced rules will be added with subsequent updates." : "Unterstützung für fortgeschrittene Regeln wird mit späteren Aktualisierungen hinzugefügt werden.",
     "Reset repeating rule" : "Wiederholungsregel zurücksetzen",
-    "Repeat every ..." : "Wiederholen alle …",
+    "Repeat every ..." : "Wiederholen jeden …",
     "end repeat ..." : "Wiederholung beenden …",
-    "times" : "mal",
+    "times" : "Mal",
     "Import Calendars" : "Kalender importieren",
-    "Import canceled" : "Import abgebrochen",
-    "Analyzing calendar" : "Analysiere Kalender",
+    "Import canceled" : "Importieren abgebrochen",
+    "Analyzing calendar" : "Kalender analysieren",
     "The file contains objects incompatible with the selected calendar" : "Die Datei enthält Objekte, die nicht mit dem ausgewählten Kalender kompatibel sind",
     "New calendar" : "Neuer Kalender",
     "File is empty" : "Datei ist leer",
     "Import scheduled" : "Import geplant",
     "%s shared the calendar <strong>%s</strong> with you" : "%s hat den Kalender  <strong>%s</strong> mit Dir geteilt",
     "Embed" : "Einbetten",
-    "IFrame to integrate" : "Iframe zum Einbinden",
+    "Iframe to integrate" : "Iframe zum Einbinden",
     "Publish URL" : "URL veröffentlichen",
     "Settings & import" : "Einstellungen & Import",
     "Skip simple event editor" : "Einfachen Ereignis-Editor überspringen",
