@@ -2,6 +2,7 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Egutegia",
+    "Hello," : "Kaixo,",
     "Individual" : "Bakarkakoa",
     "Group" : "Taldea",
     "Unknown" : "Ezezaguna",
@@ -26,7 +27,6 @@ OC.L10N.register(
     "1 hour before" : "Ordu 1 lehenago",
     "2 hours before" : "2 ordu lehenago",
     "Audio" : "Audio",
-    "E Mail" : "E-Mail",
     "min" : "min",
     "hours" : "ordu",
     "days" : "egun",
@@ -35,7 +35,6 @@ OC.L10N.register(
     "start" : "Hasi",
     "end" : "bukatu",
     "Week {number} of {year}" : "{year}ko {number} astea",
-    "E-Mail" : "E-posta",
     "Title of the Event" : "Gertaeraren izenburua",
     "All day Event" : "Egun osoko gertaera",
     "Delete" : "Ezabatu",
@@ -47,7 +46,6 @@ OC.L10N.register(
     "Location" : "Kokapena",
     "Description" : "Deskribapena",
     "Export" : "Esportatu",
-    "Hello," : "Kaixo,",
     "Day" : "Eguna",
     "Week" : "Astea",
     "Month" : "Hilabetea",
