@@ -2,11 +2,15 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "تقویم",
+    "Hello," : "سلام،",
     "Individual" : "تک",
     "Group" : "گروه",
+    "Resource" : "منابع",
+    "Room" : "اتاق",
     "Unknown" : "نامشخص",
     "Required" : "اجباری",
     "Optional" : "اختیاری",
+    "{name} ({email})" : "{name} ({email})",
     "New event" : "رویداد جدید",
     "group" : "گروه",
     "Attendees" : "شرکت کنندگان",
@@ -21,6 +25,7 @@ OC.L10N.register(
     "never" : "هرگز",
     "after" : "بعد از",
     "Audio" : "صدا",
+    "Email" : "ایمیل",
     "sec" : "ثانیه",
     "min" : "دقیقه",
     "hours" : "ساعت",
