@@ -2,7 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalenteri",
-    "%s has published the calendar \"%s\"" : "%s julkaisi kalenterin \"%s\"",
+    "%s has published the calendar »%s«" : "%s on julkaissut kalenterin  »%s«",
+    "Hello," : "Hei,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Halusimme ilmoittaa että %s on julkaissut kalenterin »%s«.",
+    "Open »%s«" : "Avaa »%s«",
+    "Cheers!" : "Kiitos!",
+    "Recipient" : "Vastaanottaja",
     "Too many redirects. Aborting ..." : "Liian monta uudelleenohjausta. Keskeytetään ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Etäpalvelin ei antanut pääsyä kalenteriin (HTTP-virhe {%s})",
     "Error connecting to remote server" : "Virhe yhdistettäessä etäpalvelimeen",
@@ -23,8 +28,8 @@ OC.L10N.register(
     "CalDAV address for clients" : "CalDAV-osoite asiakasohjelmille",
     "Error saving WebCal-calendar" : "Virhe tallentaessa WebCal-kalenteria",
     "WebDAV address for subscriptions" : "WebDAV-osoite tilauksille",
-    "EMail has been sent." : "Sähköposti lähetetty.",
-    "There was an issue while sending your EMail." : "Virhe lähetettäessä sähköpostia.",
+    "Email has been sent." : "Sähköposti on lähetetty",
+    "There was an issue while sending your email." : "Virhe lähetettäessä sähköpostia.",
     "group" : "ryhmä",
     "Details" : "Tiedot",
     "Attendees" : "Osallistujat",
@@ -36,9 +41,9 @@ OC.L10N.register(
     "Confirmed" : "Vahvistettu",
     "Tentative" : "Alustava",
     "Cancelled" : "Peruttu",
-    "Please add a title!" : "Lisää otsikko!",
-    "Please select a calendar!" : "Valitse kalenteri!",
-    "The event ends before it starts!" : "Tapahtuman päättymisajankohta on ennen alkamisajankohtaa!",
+    "Please add a title." : "Lisää otsikko",
+    "Please select a calendar." : "Valitse kalenteri",
+    "The event can not end before it starts." : "Tapahtuma ei voi loppua ennen alkua",
     "Global" : "Julkinen",
     "None" : "Ei mitään",
     "Every day" : "Päivittäin",
@@ -57,8 +62,8 @@ OC.L10N.register(
     "2 hours before" : "2 tuntia ennen",
     "Custom" : "Omavalintainen",
     "Audio" : "Ääni",
-    "E Mail" : "Sähköposti",
-    "Pop up" : "Ponnahdus",
+    "Email" : "Sähköposti",
+    "Pop-up" : "Ponnahdusikkuna",
     "sec" : "s",
     "min" : "min",
     "hours" : "tuntia",
@@ -73,8 +78,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Tuotu osittain, 1 epäonnistui",
     "Partially imported, {n} failures" : "Tuotu osittain, {n} epäonnistui",
     "Audio alarm" : "Äänihälytys",
-    "Pop-up" : "Ponnahdusikkuna",
-    "E-Mail" : "Sähköposti",
     "{type} {time} before the event starts" : "{type} {time} ennen tapahtuman alkua",
     "{type} {time} before the event ends" : "{type} {time} ennen tapahtuman loppua",
     "{type} {time} after the event starts" : "{type} {time} tapahtuman alkamisen jälkeen",
@@ -101,13 +104,10 @@ OC.L10N.register(
     "Visibility when sharing" : "Näkyvyys jaettaessa",
     "Export" : "Vie",
     "%s has published the calendar %s" : "%s julkaisi kalenterin %s",
-    "Hello," : "Hei,",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin {boldstart}%s{boldend}.",
     "Click here to access it" : "Klikkaa tästä päästäksesi siihen käsiksi",
-    "Cheers!" : "Kiitos!",
     "We wanted to inform you that %s has published the calendar %s." : "Halusimme ilmoittaa, että %s on julkaissut kalenterin %s.",
     "Click on the link below to access it" : "Klikkaa alla olevaa linkkiä päästäksesi siihen käsiksi",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Ota yhteys ylläpitoon ja pyydä poistamaan käytöstä valinta \"asset-pipeline.enabled\" asetustiedostosta.",
     "Day" : "Päivä",
     "Week" : "Viikko",
     "Month" : "Kuukausi",
@@ -143,7 +143,7 @@ OC.L10N.register(
     "Repeat" : "Kertaa",
     "times every" : "kertaa joka",
     "Add" : "Lisää",
-    "E-Mail address of attendee" : "Osallistujan sähköpostiosoite",
+    "Email address of attendee" : "Osallistujan sähköpostiosoite",
     "Please add your email address in the personal settings in order to add attendees." : "Lisää sähköpostiosoitteesi henkilökohtaisiin asetuksiin, jotta voit lisätä osallistujia.",
     "from" : "alkaen",
     "to" : "päättyen",
@@ -162,7 +162,7 @@ OC.L10N.register(
     "Import scheduled" : "Tuonti ajastettu",
     "%s shared the calendar <strong>%s</strong> with you" : "%s jakoi kalenterin<strong>%s</strong>sinulle",
     "Embed" : "Upota",
-    "IFrame to integrate" : "IFrame integraatio",
+    "Iframe to integrate" : "Integroitava iframe",
     "Publish URL" : "Julkaise URL",
     "Settings & import" : "Asetukset ja tuonti",
     "Skip simple event editor" : "Ohita yksinkertainen tapahtumamuokkain",
