@@ -24,8 +24,6 @@ OC.L10N.register(
     "Confirmed" : "מאושר",
     "Tentative" : "אישור טנטטיבי",
     "Cancelled" : "בוטל",
-    "Please add a title!" : "יש להוסיף כותרת!",
-    "Please select a calendar!" : "יש לבחור לוח שנה!",
     "Global" : "גלובלי",
     "None" : "כלום",
     "Every day" : "כל יום",
@@ -43,8 +41,7 @@ OC.L10N.register(
     "2 hours before" : "2 שעות לפני",
     "Custom" : "מותאם אישית",
     "Audio" : "קובץ שמע",
-    "E Mail" : "דואר אלקטרוני",
-    "Pop up" : "חלון קופץ",
+    "Pop-up" : "חלון קופץ",
     "sec" : "שניות",
     "min" : "דקות",
     "hours" : "שעות",
@@ -59,8 +56,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "יובא חלקית, 1 שגיאה",
     "Partially imported, {n} failures" : "יובא חלקית, {n} שגיאות",
     "Audio alarm" : "תזכורת קולית",
-    "Pop-up" : "חלון קופץ",
-    "E-Mail" : "דואר אלקטרוני",
     "{type} {time} before the event starts" : "{type} {time} לפני תחילת האירוע",
     "{type} {time} before the event ends" : "{type} {time} לפני סיום האירוע",
     "{type} {time} after the event starts" : "{type} {time} אחרי תחילת האירוע",
@@ -83,8 +78,6 @@ OC.L10N.register(
     "Event status" : "סטטוס אירוע",
     "Visibility when sharing" : "הרשאות צפייה כשמשתפים",
     "Export" : "ייצוא",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "בשל באג upstream, היומן לא יכול לספק תמיכה לתכונת asset pipeline.",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "יש ליצור קשר עם המנהל שלך לבקש לנטרל את אפשרות תצורה \"asset-pipeline.enabled\".",
     "Day" : "יום",
     "Week" : "שבוע",
     "Month" : "חודש",
@@ -111,7 +104,6 @@ OC.L10N.register(
     "Repeat" : "חזרה",
     "times every" : "פעמים כל",
     "Add" : "הוספה",
-    "E-Mail address of attendee" : "כתובת דואר אלקטרוני של משתתף",
     "Please add your email address in the personal settings in order to add attendees." : "יש להזין את כתובת הדואר האלקטרוני שלך בהגדרות האישיות בכדי להוסיף מוזמנים.",
     "from" : "מאת",
     "to" : "אל",
