@@ -26,7 +26,6 @@ OC.L10N.register(
     "30 minutes before" : "30 րոպե առաջ",
     "1 hour before" : "1 ժամ առաջ",
     "2 hours before" : "2 ժամ առաջ",
-    "E Mail" : "Էլ. փոստ",
     "sec" : "վրկ",
     "min" : "րոպե",
     "hours" : "ժամ",
@@ -37,7 +36,6 @@ OC.L10N.register(
     "Successfully imported" : "Հաջողությամբ ներմուծվեց",
     "Partially imported, 1 failure" : "Մասնակի ներմուծվեց, 1 ձախողում",
     "Partially imported, {n} failures" : "Մասնակի ներմուծվեց, {n} ձախողում",
-    "E-Mail" : "Էլ. նամակ",
     "{type} {time} before the event starts" : "{type} {time} մինչ միջոցառման սկիզբը",
     "{type} {time} before the event ends" : "{type} {time} մինչ միջոցառման ավարտը",
     "{type} {time} after the event starts" : "{type} {time} միջոցառման սկզբից հետո",
@@ -83,7 +81,6 @@ OC.L10N.register(
     "Repeat" : "Կրկնել",
     "times every" : "անգամ ամեն",
     "Add" : "Ավելացնել",
-    "E-Mail address of attendee" : "Մասնակցի էլ. հասցե",
     "Please add your email address in the personal settings in order to add attendees." : "Մասնակիցներ ավելացնելու համար անձնական կարգավորումներում նշեք էլ. հասցե:",
     "Repeat every ..." : "Կրկնել ամեն ...",
     "times" : "անգամ",
