@@ -2,7 +2,8 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendario",
-    "%s has published the calendar \"%s\"" : "%s ha publicate le calendario \"%s\"",
+    "Hello," : "Salute %s,",
+    "Cheers!" : "Congratulationes!",
     "Too many redirects. Aborting ..." : "Troppo redirectiones. Annullante ....",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Le servitor remote non dava nos accesso al calendario (error HTTP {%s})",
     "Error connecting to remote server" : "Error durante que connecteva al servitor remote",
@@ -23,8 +24,6 @@ OC.L10N.register(
     "CalDAV address for clients" : "Adresse CalDAV pro clientes",
     "Error saving WebCal-calendar" : "Error durante que salveguardava calendario WebCal",
     "WebDAV address for subscriptions" : "Adresse WebDAV pro subscriptiones",
-    "EMail has been sent." : "E-posta esseva inviate.",
-    "There was an issue while sending your EMail." : "Il occurreva un error durante que tu message de e-posta esseva inviate.",
     "group" : "gruppo",
     "Details" : "Detalios",
     "Attendees" : "Participantes",
@@ -36,9 +35,6 @@ OC.L10N.register(
     "Confirmed" : "Confirmate",
     "Tentative" : "Tentative",
     "Cancelled" : "Annullate",
-    "Please add a title!" : "Per favor adde un titulo",
-    "Please select a calendar!" : "Per favor selectiona un calendario ",
-    "The event ends before it starts!" : "Le evento fini ante su initio!",
     "Global" : "Global",
     "None" : "Nulle",
     "Every day" : "Quotidianmente",
@@ -57,8 +53,7 @@ OC.L10N.register(
     "2 hours before" : "2 horas antea",
     "Custom" : "Personalisate",
     "Audio" : "Audio",
-    "E Mail" : "E-posta",
-    "Pop up" : "Pop-up",
+    "Pop-up" : "Pop-up",
     "sec" : "secundas",
     "min" : "minutas",
     "hours" : "horas",
@@ -73,8 +68,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Partialmente importate, 1 fallimento",
     "Partially imported, {n} failures" : "Partialmente importate, {n} fallimentos",
     "Audio alarm" : "Alarma in audio",
-    "Pop-up" : "Pop-up",
-    "E-Mail" : "E-posta",
     "{type} {time} before the event starts" : "{type} {time} ante que le evento initia",
     "{type} {time} before the event ends" : "{type} {time} ante que le evento fini",
     "{type} {time} after the event starts" : "{type} {time} post que le evento initia",
@@ -101,14 +94,10 @@ OC.L10N.register(
     "Visibility when sharing" : "Visibilitate quando compartite",
     "Export" : "Exportar",
     "%s has published the calendar %s" : "%s ha publicate le calendario %s",
-    "Hello," : "Salute %s,",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Nos vole informar te que %s ha publicate le calendario {boldstart}%s{boldend}.",
     "Click here to access it" : "Clicca ci pro acceder lo.",
-    "Cheers!" : "Congratulationes!",
     "We wanted to inform you that %s has published the calendar %s." : "Nos vole informar te que %s ha publicate le calendario %s.",
     "Click on the link below to access it" : "Clicca super le ligamine infra pro acceder lo",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa de un defecto ex le fonte, le calendario actualmente non es capace a provider supporto al function de tubo active.",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Per favor, contacta tu administrator e sollicita le pro disactivar le option de configuration \"asset-pipeline.enabled\".",
     "Day" : "Die",
     "Week" : "Septimana",
     "Month" : "Mense",
@@ -142,7 +131,6 @@ OC.L10N.register(
     "Repeat" : "Repeter",
     "times every" : "vices tote",
     "Add" : "Adder",
-    "E-Mail address of attendee" : "Adresse de e-posta del participante",
     "Please add your email address in the personal settings in order to add attendees." : "Per favor, adde tu adresse de e-posta in le configurationes personal pro adder participantes.",
     "from" : "ex",
     "to" : "a",
