@@ -2,7 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Calendario",
-    "%s has published the calendar \"%s\"" : "%s ha pubblicato il calendario \"%s\"",
+    "%s has published the calendar »%s«" : "%s ha pubblicato il calendario «%s»",
+    "Hello," : "Ciao,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Ti vogliamo informare che %s ha pubblicato il calendario «%s». ",
+    "Open »%s«" : "Apri «%s»",
+    "Cheers!" : "Evviva!",
+    "Recipient" : "Destinatario",
     "Too many redirects. Aborting ..." : "Troppe redirezioni. Interruzione in corso...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Il server remoto ha negato l'accesso al calendario (errore HTTP {%s})",
     "Error connecting to remote server" : "Errore durante la connessione al server remoto",
@@ -23,8 +28,8 @@ OC.L10N.register(
     "CalDAV address for clients" : "Indirizzo CalDAV per i client",
     "Error saving WebCal-calendar" : "Errore durante il salvataggio del calendario WebCal",
     "WebDAV address for subscriptions" : "Indirizzo WebDAV per le sottoscrizioni",
-    "EMail has been sent." : "Il messaggio è stata inviato.",
-    "There was an issue while sending your EMail." : "C'è stato un problema durante l'invio del tuo messaggio.",
+    "Email has been sent." : "Il messaggio è stata inviato.",
+    "There was an issue while sending your email." : "Si è verificato un problema durante l'invio del tuo messaggio.",
     "group" : "gruppo",
     "Details" : "Dettagli",
     "Attendees" : "Partecipanti",
@@ -36,9 +41,9 @@ OC.L10N.register(
     "Confirmed" : "Confermato",
     "Tentative" : "Provvisorio",
     "Cancelled" : "Annullato",
-    "Please add a title!" : "Aggiungi un titolo!",
-    "Please select a calendar!" : "Seleziona un calendario!",
-    "The event ends before it starts!" : "L'evento termina prima del suo inizio!",
+    "Please add a title." : "Aggiungi un titolo.",
+    "Please select a calendar." : "Seleziona un calendario.",
+    "The event can not end before it starts." : "L'evento non può terminare prima del suo inizio.",
     "Global" : "Globale",
     "None" : "Nessuno",
     "Every day" : "Ogni giorno",
@@ -57,8 +62,8 @@ OC.L10N.register(
     "2 hours before" : "2 ore prima",
     "Custom" : "Personalizzato",
     "Audio" : "Audio",
-    "E Mail" : "Posta elettronica",
-    "Pop up" : "Finestra a comparsa",
+    "Email" : "Email",
+    "Pop-up" : "Finestra a comparsa",
     "sec" : "sec",
     "min" : "min",
     "hours" : "ore",
@@ -73,15 +78,13 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Importato parzialmente, 1 problema",
     "Partially imported, {n} failures" : "Importato parzialmente, {n} problemi",
     "Audio alarm" : "Avviso sonoro",
-    "Pop-up" : "Finestra a comparsa",
-    "E-Mail" : "Posta elettronica",
     "{type} {time} before the event starts" : "{type} {time} prima dell'inizio dell'evento",
     "{type} {time} before the event ends" : "{type} {time} prima della fine dell'evento",
     "{type} {time} after the event starts" : "{type} {time} dopo l'inizio dell'evento",
     "{type} {time} after the event ends" : "{type} {time} dopo la fine dell'evento",
     "{type} at the event's start" : "{type} all'inizio dell'evento",
     "{type} at the event's end" : "{type} alla fine dell'evento",
-    "{type} at {time}" : "{type} alle {time}",
+    "{type} at {time}" : "{type} il {time}",
     "{calendar} shared by {owner}" : "{calendar} condiviso da {owner}",
     "Please enter a valid WebCal-URL" : "Digita un URL WebCal valido",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Errore grave nel proxy webcal. Contatta l'amministratore per ulteriori informazioni.",
@@ -101,14 +104,10 @@ OC.L10N.register(
     "Visibility when sharing" : "Visibilità in caso di condivisione",
     "Export" : "Esporta",
     "%s has published the calendar %s" : "%s ha pubblicato il calendario %s",
-    "Hello," : "Ciao,",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Ti vogliamo informare che %s ha pubblicato il calendario {boldstart}%s{boldend}.",
     "Click here to access it" : "Fai clic qui per accedere",
-    "Cheers!" : "Evviva!",
     "We wanted to inform you that %s has published the calendar %s." : "Ti vogliamo informare che %s ha pubblicato il calendario %s.",
     "Click on the link below to access it" : "Fai clic sul collegamento sotto per accedere",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "A causa di un bug a monte, il calendario non è attualmente in grado di fornire supporto per la funzionalità di asset pipeline.",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Contatta il tuo amministratore e chiedigli di disabilitare l'opzione di configurazione \"asset-pipeline.enabled\".",
     "Day" : "Giorno",
     "Week" : "Settimana",
     "Month" : "Mese",
@@ -132,6 +131,8 @@ OC.L10N.register(
     "New Subscription" : "Nuova sottoscrizione",
     "Go back" : "Indietro",
     "Go forward" : "Avanti",
+    "Calendar does not exist" : "Il calendario non esiste",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Potresti ricevuto un collegamento errato o il calendario non è più condiviso?",
     "Edit event" : "Modifica evento",
     "Delete Event" : "Elimina evento",
     "Save Event" : "Salva evento",
@@ -142,7 +143,7 @@ OC.L10N.register(
     "Repeat" : "Ripeti",
     "times every" : "volte ogni",
     "Add" : "Aggiungi",
-    "E-Mail address of attendee" : "Indirizzo email del partecipante",
+    "Email address of attendee" : "Indirizzo email del partecipante",
     "Please add your email address in the personal settings in order to add attendees." : "Aggiungi il tuo indirizzo email nelle impostazioni personali per aggiungere i partecipanti.",
     "from" : "da",
     "to" : "a",
@@ -159,6 +160,9 @@ OC.L10N.register(
     "New calendar" : "Nuovo calendario",
     "File is empty" : "Il file è vuoto",
     "Import scheduled" : "Importa pianificati",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s ha condiviso il calendario <strong>%s</strong> con te",
+    "Embed" : "Integra",
+    "Iframe to integrate" : "Iframe da integrare",
     "Publish URL" : "Pubblica URL",
     "Settings & import" : "Impostazioni e importazione",
     "Skip simple event editor" : "Salta l'editor semplice degli eventi",
@@ -166,6 +170,7 @@ OC.L10N.register(
     "Import calendar" : "Importa calendario",
     "No Calendars selected for import" : "Nessun calendario selezionato per l'importazione",
     "Primary CalDAV address" : "Indirizzo CalDAV principale",
-    "iOS/OS X CalDAV address" : "Indirizzo CalDAV iOS/OS X"
+    "iOS/OS X CalDAV address" : "Indirizzo CalDAV iOS/OS X",
+    "Subscribe" : "Sottoscrivi"
 },
 "nplurals=2; plural=(n != 1);");
