@@ -2,7 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "カレンダー",
-    "%s has published the calendar \"%s\"" : "%sさんがカレンダー \"%s\"を公開しました",
+    "%s has published the calendar »%s«" : "%sをカレンダー »%s«に登録しました",
+    "Hello," : "こんにちは。",
+    "We wanted to inform you that %s has published the calendar »%s«." : "%sがカレンダー»%s«に登録されましたのでお知らせします。",
+    "Open »%s«" : "»%s«を開く",
+    "Cheers!" : "それでは！",
+    "Recipient" : "受信者",
     "Too many redirects. Aborting ..." : "リダイレクトが多すぎます。 中止します...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "リモートサーバーのカレンダーにアクセスできませんでした（HTTP {%s}エラー）",
     "Error connecting to remote server" : "リモートサーバーに接続中にエラーが発生しました",
@@ -23,8 +28,8 @@ OC.L10N.register(
     "CalDAV address for clients" : "クライアントのCalDAVアドレス",
     "Error saving WebCal-calendar" : "WebCalカレンダーの保存中にエラーが発生しました",
     "WebDAV address for subscriptions" : "サブスクリプションのWebDAVアドレス",
-    "EMail has been sent." : "メールが送信されました。",
-    "There was an issue while sending your EMail." : "あなたのEメールを送信中に問題が発生しました。",
+    "Email has been sent." : "電子メールが送られました",
+    "There was an issue while sending your email." : "メールの送信に問題があります。",
     "group" : "グループ",
     "Details" : "詳細",
     "Attendees" : "参加者",
@@ -36,9 +41,9 @@ OC.L10N.register(
     "Confirmed" : "確認されました",
     "Tentative" : "暫定的",
     "Cancelled" : "キャンセル済",
-    "Please add a title!" : "タイトルを追加してください！",
-    "Please select a calendar!" : "カレンダーを選択してください！",
-    "The event ends before it starts!" : "イベントが開始前に終了します!",
+    "Please add a title." : "タイトルをつけてください。",
+    "Please select a calendar." : "カレンダーを選択してください。",
+    "The event can not end before it starts." : "イベントは開始前に終了できません。",
     "Global" : "全般",
     "None" : "なし",
     "Every day" : "毎日",
@@ -57,8 +62,8 @@ OC.L10N.register(
     "2 hours before" : "2時間前",
     "Custom" : "カスタム",
     "Audio" : "オーディオ",
-    "E Mail" : "Eメール",
-    "Pop up" : "ポップアップ",
+    "Email" : "電子メール",
+    "Pop-up" : "ポップアップ",
     "sec" : "秒",
     "min" : "最低",
     "hours" : "時間",
@@ -73,8 +78,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "不完全なインポート，失敗1",
     "Partially imported, {n} failures" : "不完全なインポート，失敗{n}",
     "Audio alarm" : "オーディオアラーム",
-    "Pop-up" : "ポップアップ",
-    "E-Mail" : "メール",
     "{type} {time} before the event starts" : "イベント開始の{type} {time} 前",
     "{type} {time} before the event ends" : "イベント終了の{type} {time} 前",
     "{type} {time} after the event starts" : "イベント開始の{type} {time} 後",
@@ -101,14 +104,10 @@ OC.L10N.register(
     "Visibility when sharing" : "共有時の可視性",
     "Export" : "エクスポート",
     "%s has published the calendar %s" : "%sはカレンダー%sを公開しました",
-    "Hello," : "こんにちは。",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "%s が {boldstart}%s{boldend} カレンダーを公開したので通知します。",
     "Click here to access it" : "それにアクセスするにはここをクリック",
-    "Cheers!" : "それでは！",
     "We wanted to inform you that %s has published the calendar %s." : "%sはカレンダー%sを公開しました",
     "Click on the link below to access it" : "それにアクセスするには下をクリック",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "流れをさかのぼるバグのため、カレンダーは現在、アセットパイプライン機能のサポートを提供することができません。",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "管理者に連絡して、「asset-pipeline.enabled」オプションを無効にするよう依頼してください。",
     "Day" : "日",
     "Week" : "週",
     "Month" : "月",
@@ -132,6 +131,8 @@ OC.L10N.register(
     "New Subscription" : "新しい購読",
     "Go back" : "戻る",
     "Go forward" : "進む",
+    "Calendar does not exist" : "カレンダーが存在しません。",
+    "Maybe you got a wrong link or the calendar was unshared?" : "リンクが間違っているかカレンダーが共有されていないようです。",
     "Edit event" : "イベントを編集",
     "Delete Event" : "イベントを削除",
     "Save Event" : "イベントを保存",
@@ -142,7 +143,7 @@ OC.L10N.register(
     "Repeat" : "繰り返し",
     "times every" : "繰り返し",
     "Add" : "追加",
-    "E-Mail address of attendee" : "参加者のメールアドレス",
+    "Email address of attendee" : "参加者の電子メールアドレス",
     "Please add your email address in the personal settings in order to add attendees." : "出席者に追加するにはアカウント設定でメールアドレスを追加してください",
     "from" : "差出人",
     "to" : "宛先",
@@ -159,6 +160,9 @@ OC.L10N.register(
     "New calendar" : "新しいカレンダー",
     "File is empty" : "ファイルが空です",
     "Import scheduled" : "スケジュールのインポート",
+    "%s shared the calendar <strong>%s</strong> with you" : "%sはカレンダー<strong>%s</strong>をあなたと共有しています。",
+    "Embed" : "埋め込み",
+    "Iframe to integrate" : "Iframeの統合",
     "Publish URL" : "URLを公開する",
     "Settings & import" : "設定とインポート",
     "Skip simple event editor" : "シンプルイベントエディタをスキップ",
@@ -166,6 +170,7 @@ OC.L10N.register(
     "Import calendar" : "カレンダーのインポート",
     "No Calendars selected for import" : "インポートするカレンダーが指定されていません",
     "Primary CalDAV address" : "一番目の CalDAV アドレス",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV アドレス"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV アドレス",
+    "Subscribe" : "購読"
 },
 "nplurals=1; plural=0;");
