@@ -2,7 +2,8 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "달력",
-    "%s has published the calendar \"%s\"" : "%s 님이 달력 \"%s\"을(를) 공개했습니다",
+    "Hello," : "안녕하세요,",
+    "Cheers!" : "감사합니다!",
     "Too many redirects. Aborting ..." : "너무 많은 넘겨주기, 중단합니다 ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "원격 서버에서 달력 접근을 허용하지 않음 (HTTP 오류 {%s})",
     "Error connecting to remote server" : "원격 서버 연결 오류",
@@ -23,8 +24,6 @@ OC.L10N.register(
     "CalDAV address for clients" : "클라이언트를 위한 CalDAV 주소",
     "Error saving WebCal-calendar" : "WebCal 달력을 저장하는 중 오류 발생",
     "WebDAV address for subscriptions" : "구독에 사용할 WebDAV 주소",
-    "EMail has been sent." : "이메일을 전송했습니다.",
-    "There was an issue while sending your EMail." : "이메일을 보내는 중 오류가 발생했습니다.",
     "group" : "그룹",
     "Details" : "자세한 정보",
     "Attendees" : "참석자",
@@ -36,9 +35,6 @@ OC.L10N.register(
     "Confirmed" : "확인됨",
     "Tentative" : "예정됨",
     "Cancelled" : "취소됨",
-    "Please add a title!" : "제목을 입력하십시오!",
-    "Please select a calendar!" : "달력을 선택하십시오!",
-    "The event ends before it starts!" : "일정이 끝나는 시간이 시작 시간보다 빠릅니다!",
     "Global" : "전역",
     "None" : "없음",
     "Every day" : "매일",
@@ -57,8 +53,7 @@ OC.L10N.register(
     "2 hours before" : "2시간 전",
     "Custom" : "사용자 정의",
     "Audio" : "오디오",
-    "E Mail" : "이메일",
-    "Pop up" : "팝업",
+    "Pop-up" : "팝업",
     "sec" : "초",
     "min" : "분",
     "hours" : "시간",
@@ -73,8 +68,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "일부만 가져옴, 1개 항목 실패",
     "Partially imported, {n} failures" : "일부만 가져옴, {n}개 항목 실패",
     "Audio alarm" : "오디오 알람",
-    "Pop-up" : "팝업",
-    "E-Mail" : "이메일",
     "{type} {time} before the event starts" : "일정 시작 {time} 전 {type}",
     "{type} {time} before the event ends" : "일정 종료 {time} 전 {type}",
     "{type} {time} after the event starts" : "일정 시작 {time} 후 {type}",
@@ -101,14 +94,10 @@ OC.L10N.register(
     "Visibility when sharing" : "공유할 때 표시 여부",
     "Export" : "내보내기",
     "%s has published the calendar %s" : "%s 님이 달력 %s을(를) 공개했습니다",
-    "Hello," : "안녕하세요,",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "%s 님이 달력 {boldstart}%s{boldend}을(를) 공개했음을 알려 드립니다.",
     "Click here to access it" : "접근하려면 여기를 누르십시오",
-    "Cheers!" : "감사합니다!",
     "We wanted to inform you that %s has published the calendar %s." : "%s 님이 달력 %s을(를) 공개했음을 알려 드립니다.",
     "Click on the link below to access it" : "접근하려면 아래의 링크를 누르십시오",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "업스트림 버그로 인하여 달력에서 자원 파이프라인 기능을 지원하지 않습니다.",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "시스템 관리자에게 연락하여 \"asset-pipeline.enabled\" 설정 옵션을 비활성화할 것을 요청하십시오.",
     "Day" : "일",
     "Week" : "주",
     "Month" : "달",
@@ -141,7 +130,6 @@ OC.L10N.register(
     "Absolute" : "절대적",
     "Repeat" : "반복",
     "Add" : "추가",
-    "E-Mail address of attendee" : "참석자의 이메일 주소",
     "Please add your email address in the personal settings in order to add attendees." : "참석자 목록을 편집하려면 개인 설정에서 이메일 주소를 추가하십시오.",
     "from" : "시작",
     "to" : "끝",
