@@ -2,12 +2,17 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendorius",
-    "%s has published the calendar \"%s\"" : "%s buvo paskelbta kalendoriuje \"%s\"",
+    "%s has published the calendar »%s«" : "%s pasidalino kalendoriumi \"%s\"",
+    "Hello," : "Sveiki,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Norėtume informuoti, kad %s pasidalino kalendoriumi \"%s\"",
+    "Open »%s«" : "Atidaryti \"%s\"",
+    "Cheers!" : "Sveikinimai!",
+    "Recipient" : "Gavėjas",
     "Too many redirects. Aborting ..." : "Per daug nukreipimų. Nutraukiama ...",
-    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Nutolęs serveris neleido prisijungti prie kalendoriaus (HTTP {%s} klaida)",
-    "Error connecting to remote server" : "Klaida, jungiantis prie nuotolinio serverio",
-    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Klaida gaunant informaciją iš nutolusio serverio. Tai galimai gali būti susiję su sertifikatų neatitikimu",
-    "Error requesting resource on remote server" : "Klaida gaunant informaciją iš nutolusio serverio",
+    "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Serveris neleido prisijungti prie kalendoriaus (HTTP {%s} klaida)",
+    "Error connecting to remote server" : "Klaida, jungiantis prie serverio",
+    "Error requesting resource on remote server. This could possible be related to a certificate mismatch" : "Klaida ieškant duomenų kitame serveryje. Tai galimai gali būti susiję su liudijimų neatitikimu",
+    "Error requesting resource on remote server" : "Klaida gaunant informaciją iš kito serverio",
     "Individual" : "Individualus",
     "Group" : "Grupė",
     "Resource" : "Išteklis",
@@ -18,26 +23,27 @@ OC.L10N.register(
     "Does not attend" : "Nedalyvauja",
     "{name} ({email})" : "{name} ({email})",
     "You are in an unknown timezone ({tz}), falling back to UTC" : "Jūsų laiko juosta ({tz}) nežinoma, bus naudojama UTC laiko juosta",
-    "Please create a calendar first." : "Prašome, iš pradžių, sukurti kalendorių.",
+    "Please create a calendar first." : "Prašome sukurti kalendorių.",
     "New event" : "Naujas įvykis",
-    "CalDAV address for clients" : "CalDAV adresas klientams",
+    "CalDAV address for clients" : "CalDAV adresas",
     "Error saving WebCal-calendar" : "Klaida, įrašant WebCal kalendorių",
     "WebDAV address for subscriptions" : "WebDAV adresas prenumeratoms",
-    "EMail has been sent." : "El. laiškas išsiųstas.",
-    "There was an issue while sending your EMail." : "Klaida siunčiant el. laišką.",
+    "Email has been sent." : "El. laiškas išsiųstas.",
+    "There was an issue while sending your email." : "Siunčiant jūsų laišką įvyko klaida.",
     "group" : "grupė",
     "Details" : "Išsamiau",
     "Attendees" : "Dalyviai",
     "Reminders" : "Priminimai",
     "Repeating" : "Pasikartojimas",
-    "When shared show full event" : "Bendrinant, rodyti pilną įvykį",
-    "When shared show only busy" : "Bendrinant rodyti tik užimtą",
+    "When shared show full event" : "Bendrinant, rodyti pilną renginio informaciją",
+    "When shared show only busy" : "Bendrinant, rodyti tik užimtumą",
     "When shared hide this event" : "Bendrinant, slėpti šį įvykį",
     "Confirmed" : "Patvirtintas",
     "Tentative" : "Neapibrėžtas",
     "Cancelled" : "Atsisakyta",
-    "Please add a title!" : "Pridėkite pavadinimą!",
-    "Please select a calendar!" : "Pasirinkite kalendorių!",
+    "Please add a title." : "Prašome pridėti pavadinimą.",
+    "Please select a calendar." : "Pasirinkite kalendorių.",
+    "The event can not end before it starts." : "Įvykis negali baigtis anksčiau, nei prasideda.",
     "Global" : "Globalus",
     "None" : "Nieko",
     "Every day" : "Kas dieną",
@@ -46,7 +52,7 @@ OC.L10N.register(
     "Every year" : "Kas metus",
     "never" : "niekada",
     "after" : "prieš",
-    "How about getting started by importing some calendars?" : "Gal pradžiai norite importuoti kitus kalendorius?",
+    "How about getting started by importing some calendars?" : "Gal norėtumėte importuoti kalendorius?",
     "At time of event" : "Įvykio metu",
     "5 minutes before" : "5 minutes prieš",
     "10 minutes before" : "10 minučių prieš",
@@ -56,8 +62,8 @@ OC.L10N.register(
     "2 hours before" : "2 valandas prieš",
     "Custom" : "Kitaip",
     "Audio" : "Garsu",
-    "E Mail" : "El. paštu",
-    "Pop up" : "Iškylančiuoju langu",
+    "Email" : "Elektroninio pašto adresas",
+    "Pop-up" : "Iššokantis langas",
     "sec" : "s",
     "min" : "min.",
     "hours" : "valandos",
@@ -71,9 +77,7 @@ OC.L10N.register(
     "Successfully imported" : "Sėkmingai importuota",
     "Partially imported, 1 failure" : "Dalinai importuota, 1 klaida",
     "Partially imported, {n} failures" : "Dalinai importuota, {n} klaidų",
-    "Audio alarm" : "Gaso pranešimas",
-    "Pop-up" : "Iššokantis langas",
-    "E-Mail" : "El. paštas",
+    "Audio alarm" : "Garso pranešimas",
     "{type} {time} before the event starts" : "{type} {time} prieš įvykio pradžią",
     "{type} {time} before the event ends" : "{type} {time} prieš įvykio pabaigą",
     "{type} {time} after the event starts" : "{type} {time} po įvykio pradžios",
@@ -85,6 +89,8 @@ OC.L10N.register(
     "Please enter a valid WebCal-URL" : "Prašome įvesti tinkamą WebCal adresą",
     "Severe error in webcal proxy. Please contact administrator for more information." : "Klaida naudojant WebCal proxy. Prašome susisiekti su administratoriumi.",
     "Title of the Event" : "Įvykio pavadinimas",
+    "Starts" : "Pradžia",
+    "Ends" : "Pabaiga",
     "All day Event" : "Visos dienos įvykis",
     "Delete" : "Ištrinti",
     "Cancel" : "Atsisakyti",
@@ -98,14 +104,10 @@ OC.L10N.register(
     "Visibility when sharing" : "Matomumas dalinantis",
     "Export" : "Eksportuoti",
     "%s has published the calendar %s" : "%s paskelbė kalendorių %s",
-    "Hello," : "Sveiki,",
-    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Norime Jus informuoti, kad %s paskelbė kalendorių {boldstart}%s{boldend}.",
-    "Click here to access it" : "Paspauskite čia norėdami pamatyti",
-    "Cheers!" : "Sveikinimai!",
-    "We wanted to inform you that %s has published the calendar %s." : "Norime Jus informuoti, kad %s paskelbė kalendorių %s.",
-    "Click on the link below to access it" : "Paspauskite nuorodą norėdami pamatyti",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Dėl klaidos kalendorius šiuo metu nepalaiko \"pipeline\" funkcijos.",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Prašome susisiekti su administratoriumi ir paprašyti išjungti \"asset-pipeline.enabled\" nustatymą.",
+    "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Norime jus informuoti, kad %s pasidalino kalendorių {boldstart}%s{boldend}.",
+    "Click here to access it" : "Norėdami pamatyti paspauskite čia ",
+    "We wanted to inform you that %s has published the calendar %s." : "Norime Jus informuoti, kad %s pasidalino kalendorių %s.",
+    "Click on the link below to access it" : "Norėdami pamatyti paspauskite nuorodą ",
     "Day" : "Diena",
     "Week" : "Savaitė",
     "Month" : "Mėnuo",
@@ -129,6 +131,8 @@ OC.L10N.register(
     "New Subscription" : "Nauja prenumerata",
     "Go back" : "Atgal",
     "Go forward" : "Pirmyn",
+    "Calendar does not exist" : "Kalendorius neegzistuoja",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Galbūt gavote blogą nuorodą? Gal kalendorius nesidalinamas?",
     "Edit event" : "Redaguoti įvykį",
     "Delete Event" : "Ištrinti įvykį",
     "Save Event" : "Įrašyti įvykį",
@@ -139,7 +143,7 @@ OC.L10N.register(
     "Repeat" : "Kartoti",
     "times every" : "kartų kiekvieną",
     "Add" : "Pridėti",
-    "E-Mail address of attendee" : "Dalyvaujančiųjų el. pašto adresai",
+    "Email address of attendee" : "Dalyvio elektroninio pašto adresas",
     "Please add your email address in the personal settings in order to add attendees." : "Pridėkite savo el. pašto adresą norėdami pakviesti dalyvius.",
     "from" : "iš",
     "to" : "į",
@@ -156,6 +160,9 @@ OC.L10N.register(
     "New calendar" : "Naujas kalendorius",
     "File is empty" : "Failas tuščias",
     "Import scheduled" : "Importavimas suplanuotas",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s pasidalino kalendoriumi <strong>%s</strong> su jumis",
+    "Embed" : "Įterpti",
+    "Iframe to integrate" : "Langas, kurį reikia įterpti",
     "Publish URL" : "Skelbti adresą",
     "Settings & import" : "Nustatymai ir importavimas",
     "Skip simple event editor" : "Praleisti paprastą įvykių redaktorių",
@@ -163,6 +170,7 @@ OC.L10N.register(
     "Import calendar" : "Importuoti kalendorių",
     "No Calendars selected for import" : "Nepasirinktas kalendorius importavimui",
     "Primary CalDAV address" : "Pirminis CalDAV adresas",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresas"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresas",
+    "Subscribe" : "Prenumeruoti"
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && (n%100<10 || n%100>=20) ? 1 : 2);");
