@@ -2,7 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalender",
-    "%s has published the calendar \"%s\"" : "%s har publisert kalenderen \"%s\"",
+    "%s has published the calendar »%s«" : "%s har publisert kalenderen \"%s\"",
+    "Hello," : "Hei,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Vi ønsker å informere deg om at %s har publisert kalenderen \"%s\".",
+    "Open »%s«" : "Åpne \"%s\"",
+    "Cheers!" : "Ha det!",
+    "Recipient" : "Mottaker",
     "Too many redirects. Aborting ..." : "For mange videresendinger. Avbryter…",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Ekstern tjener nektet tilgang til kalenderen (HTTP {%s} error)",
     "Error connecting to remote server" : "Feil ved opprettelsen av forbindelse til tjeneren",
@@ -23,8 +28,8 @@ OC.L10N.register(
     "CalDAV address for clients" : "CalDAV adresse for klienter",
     "Error saving WebCal-calendar" : "Feil under lagring av WebCal-kalender",
     "WebDAV address for subscriptions" : "WebDAV-adresse for abonnementer",
-    "EMail has been sent." : "E-post er sendt",
-    "There was an issue while sending your EMail." : "Problem ved forsendelse av din e-post.",
+    "Email has been sent." : "E-post er sendt.",
+    "There was an issue while sending your email." : "Problem ved forsendelse av din e-post.",
     "group" : "gruppe",
     "Details" : "Detaljer",
     "Attendees" : "Deltakere",
@@ -36,9 +41,9 @@ OC.L10N.register(
     "Confirmed" : "Bekreftet",
     "Tentative" : "Foreløpig",
     "Cancelled" : "Avbrutt",
-    "Please add a title!" : "Legg til en tittel!",
-    "Please select a calendar!" : "Velg en kalender.",
-    "The event ends before it starts!" : "Hendelsen slutter før den starter!",
+    "Please add a title." : "Legg til tittel.",
+    "Please select a calendar." : "Velg en kalender.",
+    "The event can not end before it starts." : "Hendelsen kan ikke slutte før den starter.",
     "Global" : "Global",
     "None" : "Ingen",
     "Every day" : "Hver dag",
@@ -57,8 +62,8 @@ OC.L10N.register(
     "2 hours before" : "2 timer før",
     "Custom" : "Brukervalgt",
     "Audio" : "Lyd",
-    "E Mail" : "E-post",
-    "Pop up" : "Oppsprett",
+    "Email" : "E-post",
+    "Pop-up" : "Oppsprett",
     "sec" : "sek",
     "min" : "min",
     "hours" : "timer",
@@ -73,8 +78,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Delvis importert, 1 feil",
     "Partially imported, {n} failures" : "Delvis importert, {n} feil",
     "Audio alarm" : "Lydsignal",
-    "Pop-up" : "Oppsprett",
-    "E-Mail" : "E-post",
     "{type} {time} before the event starts" : "{type} {time} før hendelsen starter",
     "{type} {time} before the event ends" : "{type} {time} før hendelsen slutter",
     "{type} {time} after the event starts" : "{type} {time} etter hendelsen starter",
@@ -101,19 +104,15 @@ OC.L10N.register(
     "Visibility when sharing" : "Synlighet ved deling",
     "Export" : "Eksporter",
     "%s has published the calendar %s" : "%s har publisert kalenderen %s",
-    "Hello," : "Hei,",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Vi ønsker å informere deg om at %s har publisert kalenderen {boldstart}%s{boldend}.",
     "Click here to access it" : "Klikk her for å åpne den",
-    "Cheers!" : "Ha det!",
     "We wanted to inform you that %s has published the calendar %s." : "Vi ønsker å informere deg om at %s har publisert kalenderen %s.",
     "Click on the link below to access it" : "Klikk på lenken under for å åpne den.",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Pga. en feil oppstrøms, støtter kalenderen for tiden ikke \"asset pipeline\".",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Kontakt administratoren og be dem skru av valget \"asset-pipeline.enabled\" i oppsettet.",
     "Day" : "Dag",
     "Week" : "Uke",
     "Month" : "Måned",
     "Today" : "I dag",
-    "Some events in this calendar are broken. Please check the JS console for more info." : "Noen hendelser i kalenderen er ødelagt. Vennligst sjekk JS konsollet for mer info.",
+    "Some events in this calendar are broken. Please check the JS console for more info." : "Noen hendelser i kalenderen er ødelagt. Sjekk JS-konsollen for mer info.",
     "Share Calendar" : "Del kalender",
     "Shared" : "Delt",
     "More" : "Mer",
@@ -144,8 +143,8 @@ OC.L10N.register(
     "Repeat" : "Gjenta",
     "times every" : "ganger hver",
     "Add" : "Legg til",
-    "E-Mail address of attendee" : "E-postadresse for deltaker",
-    "Please add your email address in the personal settings in order to add attendees." : "Legg inn epost-adressen din i personlige innstillinger for å kunne legge til deltakere.",
+    "Email address of attendee" : "E-postadresse for deltaker",
+    "Please add your email address in the personal settings in order to add attendees." : "Legg inn e-postadressen din i personlige innstillinger for å kunne legge til deltakere.",
     "from" : "fra",
     "to" : "til",
     "This event's repeating rule is not supported yet." : "Hendelsens regel for gjentagelse støttes ikke ennå.",
@@ -163,7 +162,7 @@ OC.L10N.register(
     "Import scheduled" : "Importer planlagte",
     "%s shared the calendar <strong>%s</strong> with you" : "%s delte kalenderen <strong>%s</strong> med deg",
     "Embed" : "Innebygg",
-    "IFrame to integrate" : "Putt i iframe for å integrere",
+    "Iframe to integrate" : "Sett i Iframe for å integrere",
     "Publish URL" : "Offentlig URL",
     "Settings & import" : "Innstillinger og import",
     "Skip simple event editor" : "Hopp over enkelt hendelsesredigering",
