@@ -24,8 +24,6 @@ OC.L10N.register(
     "Confirmed" : "Confirmado",
     "Tentative" : "Tentativa",
     "Cancelled" : "Cancelado",
-    "Please add a title!" : "Por favor, adicione um titulo!",
-    "Please select a calendar!" : "Por favor, selecione um calendário!",
     "Global" : "Global",
     "None" : "Nenhum",
     "Every day" : "Diariamente",
@@ -43,8 +41,7 @@ OC.L10N.register(
     "2 hours before" : "2 horas antes",
     "Custom" : "Personalizado",
     "Audio" : "Áudio",
-    "E Mail" : "Correio Eletrónico",
-    "Pop up" : "Janela de Aviso",
+    "Pop-up" : "Janela de Aviso",
     "sec" : "seg.",
     "min" : "min",
     "hours" : "horas",
@@ -59,8 +56,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Parcialmente importado, 1 erro",
     "Partially imported, {n} failures" : "Parcialmente importado, {n} erros",
     "Audio alarm" : "Alarme áudio",
-    "Pop-up" : "Janela de Aviso",
-    "E-Mail" : "Correio Eletrónico",
     "{type} {time} before the event starts" : "{type} {time} antes do evento começar",
     "{type} {time} before the event ends" : "{type} {time} antes do evento terminar",
     "{type} {time} after the event starts" : "{type} {time} depois do evento começar",
@@ -82,8 +77,6 @@ OC.L10N.register(
     "Description" : "Descrição",
     "Event status" : "Estado do evento",
     "Export" : "Exportar",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "Devido a um erro próximo da fonte, o calendário atualmente não consegue dar suporte para a função de transporte do recurso.",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "Por favor, contacte o seu administrador e peça-lhe para desativar a opção de configuração \"asset-pipeline.enabled\".",
     "Day" : "Dia",
     "Week" : "Semana",
     "Month" : "Mês",
@@ -109,7 +102,6 @@ OC.L10N.register(
     "Repeat" : "Repetir",
     "times every" : "vezes a cada",
     "Add" : "Adicionar",
-    "E-Mail address of attendee" : "Endereço de e-mail do participante",
     "Please add your email address in the personal settings in order to add attendees." : "Por favor, adicione o seu endereço de e-mail nas configurações pessoais para poder adicionar participantes.",
     "from" : "de",
     "to" : "para",
