@@ -2,7 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "Kalendár",
-    "%s has published the calendar \"%s\"" : "%s zverejnil kalendár \"%s\"",
+    "%s has published the calendar »%s«" : "Používateľ %s zverejnil kalendár %s",
+    "Hello," : "Ahoj,",
+    "We wanted to inform you that %s has published the calendar »%s«." : "Chceme vás upozorniť, že používateľ %s zverejnil kalendár %s",
+    "Open »%s«" : "Otvoriť »%s«",
+    "Cheers!" : "Pekný deň!",
+    "Recipient" : "Prijímateľ",
     "Too many redirects. Aborting ..." : "Príliš veľa presmerovaní. Ruším ...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "Vzdialený server neposkytol prístup ku kalendáru (HTTP chyba {%s})",
     "Error connecting to remote server" : "Chyba pri pripájaní na vzdialený server",
@@ -23,8 +28,8 @@ OC.L10N.register(
     "CalDAV address for clients" : "CalDAV adresa pre klientov",
     "Error saving WebCal-calendar" : "Chyba pri ukladaní WebCal-kalendára",
     "WebDAV address for subscriptions" : "WebDAV adresa pre odbery",
-    "EMail has been sent." : "E-mail bol odoslaný.",
-    "There was an issue while sending your EMail." : "Počas odosielania e-mailu nastal problém.",
+    "Email has been sent." : "E-mail bol odoslaný.",
+    "There was an issue while sending your email." : "Vyskytol sa problém pri odosielaní e-mailu.",
     "group" : "skupina",
     "Details" : "Podrobnosti",
     "Attendees" : "Účastníci",
@@ -36,9 +41,9 @@ OC.L10N.register(
     "Confirmed" : "Potvrdené",
     "Tentative" : "Neistý",
     "Cancelled" : "Zrušené",
-    "Please add a title!" : "Prosím pridajte názov!",
-    "Please select a calendar!" : "Prosím vyberte kalendár",
-    "The event ends before it starts!" : "Udalosť končí skôr ako začne!",
+    "Please add a title." : "Prosím, uveďte názov.",
+    "Please select a calendar." : "Prosím, vyberte kalendár.",
+    "The event can not end before it starts." : "Udalosť končí skôr ako začne!",
     "Global" : "Globálny",
     "None" : "Žiadny",
     "Every day" : "Každý deň",
@@ -57,8 +62,8 @@ OC.L10N.register(
     "2 hours before" : "2 hodiny pred",
     "Custom" : "Vlastný",
     "Audio" : "Zvuk",
-    "E Mail" : "E-mail",
-    "Pop up" : "Vyskakovacie okno",
+    "Email" : "E-mail",
+    "Pop-up" : "Vyskakovanie okno",
     "sec" : "sek",
     "min" : "min",
     "hours" : "hodín",
@@ -73,8 +78,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "Čiastočne importovaný, 1 chyba",
     "Partially imported, {n} failures" : "Čiastočne importovaný, {n} chýb",
     "Audio alarm" : "Zvukový alarm",
-    "Pop-up" : "Vyskakovanie okno",
-    "E-Mail" : "email",
     "{type} {time} before the event starts" : "{type} {time} pred začiatkom udalosti",
     "{type} {time} before the event ends" : "{type} {time} pred koncom udalosti",
     "{type} {time} after the event starts" : "{type} {time} po začiatku udalosti",
@@ -84,6 +87,7 @@ OC.L10N.register(
     "{type} at {time}" : "{type} o {time}",
     "{calendar} shared by {owner}" : "{calendar} sprístupňuje {owner}",
     "Please enter a valid WebCal-URL" : "Zadajte prosím platnú WebCal-URL",
+    "Severe error in webcal proxy. Please contact administrator for more information." : "Závažná chyba vo webovom proxy.  Pre viac informácií prosím kontaktujte administrátora.",
     "Title of the Event" : "Názov udalosti",
     "Starts" : "Začína",
     "Ends" : "Končí",
@@ -100,10 +104,8 @@ OC.L10N.register(
     "Visibility when sharing" : "Viditelnosť pri sprístupnení",
     "Export" : "Export",
     "%s has published the calendar %s" : "%s zverejnil kalendár %s",
-    "Hello," : "Ahoj,",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "Chceme vás informovať, že %s zverejnil kalendár {boldstart}%s{boldend}.",
     "Click here to access it" : "Pre zobrazenie kliknite sem",
-    "Cheers!" : "Pekný deň!",
     "We wanted to inform you that %s has published the calendar %s." : "Chceme vás informovať, že %s zverejnil kalendár %s.",
     "Click on the link below to access it" : "Pre zobrazenie kliknite na odkaz nižšie",
     "Day" : "Deň",
@@ -129,6 +131,8 @@ OC.L10N.register(
     "New Subscription" : "Nový odber",
     "Go back" : "Ísť späť",
     "Go forward" : "Ísť dopredu",
+    "Calendar does not exist" : "Kalendár neexistuje",
+    "Maybe you got a wrong link or the calendar was unshared?" : "Zrejme máte nesprávny odkaz, alebo kalendár už nie je zdieľaný?",
     "Edit event" : "Upraviť udalosť",
     "Delete Event" : "Zmazať udalosť",
     "Save Event" : "Uložiť udalosť",
@@ -139,10 +143,11 @@ OC.L10N.register(
     "Repeat" : "Opakovať",
     "times every" : "krát každý",
     "Add" : "Pridať",
-    "E-Mail address of attendee" : "E-mail adresa účastníka",
+    "Email address of attendee" : "E-mail adresa účastníka",
     "Please add your email address in the personal settings in order to add attendees." : "Pre pridávanie účastníkov priraďte k vašemu účtu e-mailovú adresu v osobných nastaveniach.",
     "from" : "od",
     "to" : "do",
+    "This event's repeating rule is not supported yet." : "Pravidlá opakovania tejto udalosti ešte nie sú podporované.",
     "Support for advanced rules will be added with subsequent updates." : "Podpora pre rozšírené pravidlá bude pridaná v ďalších aktualizáciách.",
     "Reset repeating rule" : "Vypnúť pravidlo opakovania",
     "Repeat every ..." : "Opakovať každý ...",
@@ -155,6 +160,9 @@ OC.L10N.register(
     "New calendar" : "Nový kalendár",
     "File is empty" : "Súbor je prázdny",
     "Import scheduled" : "Import naplánovaný",
+    "%s shared the calendar <strong>%s</strong> with you" : "%s zdieľaných kalendárov <strong>%s</strong> s vami",
+    "Embed" : "Vložiť",
+    "Iframe to integrate" : "Pridať Iframe",
     "Publish URL" : "Zverejniť URL",
     "Settings & import" : "Nastavenia a import",
     "Skip simple event editor" : "Nepoužívať jednoduchý editor",
@@ -162,6 +170,7 @@ OC.L10N.register(
     "Import calendar" : "Importovať kalendár",
     "No Calendars selected for import" : "Nebol označený kalendár na import",
     "Primary CalDAV address" : "Primárna CalDAV adresa",
-    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa"
+    "iOS/OS X CalDAV address" : "iOS/OS X CalDAV adresa",
+    "Subscribe" : "Odoberať"
 },
 "nplurals=3; plural=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;");
