@@ -23,8 +23,6 @@ OC.L10N.register(
     "Confirmed" : "ได้รับการยืนยันแล้ว",
     "Tentative" : "ชั่วคราว",
     "Cancelled" : "ยกเลิกแล้ว",
-    "Please add a title!" : "กรุณาเพิ่มหัวข้อ!",
-    "Please select a calendar!" : "กรุณาเลือกปฏิทิน!",
     "Global" : "ทั่วไป",
     "None" : "ไม่มี",
     "Every day" : "ทุกวัน",
@@ -42,8 +40,7 @@ OC.L10N.register(
     "2 hours before" : "2 ชั่วโมงก่อนหน้านั้น",
     "Custom" : "กำหนดเอง",
     "Audio" : "เสียง",
-    "E Mail" : "อีเมล",
-    "Pop up" : "ป๊อปอัพ",
+    "Pop-up" : "ป๊อปอัพ",
     "sec" : "วินาที",
     "min" : "นาที",
     "hours" : "ชั่วโมง",
@@ -58,8 +55,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "นำเข้าได้แค่บางส่วน ล้มเหลวไปแล้ว 1 ",
     "Partially imported, {n} failures" : "นำเข้าได้แค่บางส่วน ล้มเหลวไปแล้ว {n}",
     "Audio alarm" : "เสียงแจ้งเตือน",
-    "Pop-up" : "ป๊อปอัพ",
-    "E-Mail" : "อีเมล",
     "{type} {time} before the event starts" : "{type} {time} ก่อนที่เหตุการณ์จะเริ่มต้น",
     "{type} {time} before the event ends" : "{type} {time} ก่อนที่เหตุการณ์จะจบลง",
     "{type} {time} after the event starts" : "{type} {time} หลังจากที่เริ่มต้นเหตุการณ์",
@@ -81,8 +76,6 @@ OC.L10N.register(
     "Event status" : "สถานะเหตุการณ์",
     "Visibility when sharing" : "แสดงผลเมื่อมีการแชร์",
     "Export" : "ส่งออก",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "เนื่องจากข้อผิดพลาดจากต้นทาง ปัจจุบันปฏิทินยังไม่ให้การสนับสนุนสำหรับคุณลักษณะ asset pipeline",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "กรุณาติดต่อผู้ดูแลระบบของคุณและขอให้ปิดการใช้งานการตั้งค่าตัวเลือก \"asset-pipeline.enabled\"",
     "Day" : "วัน",
     "Week" : "สัปดาห์",
     "Month" : "เดือน",
@@ -109,7 +102,6 @@ OC.L10N.register(
     "Repeat" : "ทำซ้ำ",
     "times every" : "ทุกครั้ง",
     "Add" : "เพิ่ม",
-    "E-Mail address of attendee" : "ที่อยู่อีเมลของผู้เข้าร่วมประชุม",
     "Please add your email address in the personal settings in order to add attendees." : "กรุณาเพิ่มที่อยู่อีเมลของคุณในการตั้งค่าส่วนบุคคลเพื่อเพิ่มผู้เข้าร่วมประชุม",
     "from" : "จาก",
     "to" : "ถึง",
