@@ -2,7 +2,12 @@ OC.L10N.register(
     "calendar",
     {
     "Calendar" : "日历",
-    "%s has published the calendar \"%s\"" : "%s 发布了 \"%s\" 日历",
+    "%s has published the calendar »%s«" : "%s 已经发布了日历 »%s«",
+    "Hello," : "你好，",
+    "We wanted to inform you that %s has published the calendar »%s«." : "我们想通知您，%s 已发布日历»%s«。",
+    "Open »%s«" : "打开 »%s«",
+    "Cheers!" : "干杯！",
+    "Recipient" : "容器",
     "Too many redirects. Aborting ..." : "太多重定向。取消中...",
     "The remote server did not give us access to the calendar (HTTP {%s} error)" : "远程服务器日程无法访问 (HTTP {%s} 错误)",
     "Error connecting to remote server" : "连接远程服务器出错",
@@ -23,8 +28,8 @@ OC.L10N.register(
     "CalDAV address for clients" : "客户的 CalDAV 地址",
     "Error saving WebCal-calendar" : "保存WebCal日历时出错",
     "WebDAV address for subscriptions" : "订阅的WebDAV地址",
-    "EMail has been sent." : "邮件已经发送。",
-    "There was an issue while sending your EMail." : "在发送您的邮件过程中出现了问题。",
+    "Email has been sent." : "邮件已经发送。",
+    "There was an issue while sending your email." : "发送邮件过程中出现了问题。",
     "group" : "群组",
     "Details" : "细节",
     "Attendees" : "参加者",
@@ -36,9 +41,9 @@ OC.L10N.register(
     "Confirmed" : "已确认",
     "Tentative" : "暂定",
     "Cancelled" : "已取消",
-    "Please add a title!" : "请添加一个标题。",
-    "Please select a calendar!" : "请选择一个日历。",
-    "The event ends before it starts!" : "事件在开始前结束！",
+    "Please add a title." : "请添加标题。",
+    "Please select a calendar." : "请选择一个日历",
+    "The event can not end before it starts." : "事件不能在开始之前结束。",
     "Global" : "全局",
     "None" : "不提醒",
     "Every day" : "每天",
@@ -57,8 +62,8 @@ OC.L10N.register(
     "2 hours before" : "2小时前",
     "Custom" : "自定义",
     "Audio" : "声音提醒",
-    "E Mail" : "邮件提醒",
-    "Pop up" : "弹窗提醒",
+    "Email" : "电子邮件",
+    "Pop-up" : "弹窗提醒",
     "sec" : "秒",
     "min" : "分钟",
     "hours" : "小时",
@@ -73,8 +78,6 @@ OC.L10N.register(
     "Partially imported, 1 failure" : "部分导入成功，1个失败",
     "Partially imported, {n} failures" : "部分导入成功，{n} 个失败",
     "Audio alarm" : "声音提醒",
-    "Pop-up" : "弹窗提醒",
-    "E-Mail" : "邮件提醒",
     "{type} {time} before the event starts" : "事件开始前 {type} {time} ",
     "{type} {time} before the event ends" : "事件结束前 {type} {time} ",
     "{type} {time} after the event starts" : "事件开始后 {type} {time} ",
@@ -101,14 +104,10 @@ OC.L10N.register(
     "Visibility when sharing" : "共享时是否可见",
     "Export" : "导出",
     "%s has published the calendar %s" : "%s 发布了日历 %s",
-    "Hello," : "你好，",
     "We wanted to inform you that %s has published the calendar {boldstart}%s{boldend}." : "我们想通知您 %s 发布了日历 {boldstart}%s{boldend}.",
     "Click here to access it" : "点这里访问",
-    "Cheers!" : "干杯！",
     "We wanted to inform you that %s has published the calendar %s." : "我们想要提醒您 %s 发布了日历 %s.",
     "Click on the link below to access it" : "点击链接访问",
-    "Due to an upstream bug, the calendar is currently not able to provide support for the asset pipeline feature." : "由于上游的bug，日历目前无法提供资产管道功能的支持。",
-    "Please contact your administrator and ask them to disable the \"asset-pipeline.enabled\" config option." : "资产管道功能被禁用，请联系系统管理员。",
     "Day" : "天",
     "Week" : "星期",
     "Month" : "月",
@@ -144,7 +143,7 @@ OC.L10N.register(
     "Repeat" : "重复",
     "times every" : "次每",
     "Add" : "增加",
-    "E-Mail address of attendee" : "参加者的邮箱地址",
+    "Email address of attendee" : "参加者的邮箱地址",
     "Please add your email address in the personal settings in order to add attendees." : "请在个人设置中设置您的邮箱地址以便添加为参与者",
     "from" : "从",
     "to" : "到",
@@ -163,7 +162,7 @@ OC.L10N.register(
     "Import scheduled" : "导入时间表",
     "%s shared the calendar <strong>%s</strong> with you" : "%s给你分享了日历 <strong>%s</strong>",
     "Embed" : "嵌入",
-    "IFrame to integrate" : "一体化框架",
+    "Iframe to integrate" : "整合iframe",
     "Publish URL" : "发布 URL",
     "Settings & import" : "设置 & 导入",
     "Skip simple event editor" : "跳过简单事件编辑器",
