@@ -9,8 +9,7 @@
 			</a>
 		</div>
 
-		<div id="logo-claim" style="display:none;"><?php p($theme->getLogoClaim()); ?></div>
-		<div id="header-right">
+		<div id="header-right" class="header-right">
 			<a href="<?php p($_['webcalURL']); ?>" id="download" class="button">
 				<span class="icon icon-public"></span>
 				<span id="download-text"><?php p($l->t('Subscribe'))?></span>
